@@ -1,38 +1,24 @@
-from __future__ import unicode_literals
 import os
 import logging
 import logging.config
 import re
 import random, string
-from datetime import datetime
+from datetime import datetime, timezone
 import xml.etree.ElementTree as ET
 import urllib
 import json
 import copy
-import sys
-import unicodedata
 
 import requests
 from requests.exceptions import ConnectionError, HTTPError, Timeout
 from bs4 import BeautifulSoup
-import pytz
 
 from . import version
 from .consts import LookupConventions as const
 from .exceptions import APIKeyMissingError
 
-UTC = pytz.UTC
-
 REDIS_LUA_DEL_SCRIPT = "local keys = redis.call('keys', ARGV[1]) \n for i=1,#keys,20000 do \n redis.call('del', unpack(keys, i, math.min(i+19999, #keys))) \n end \n return keys"
 
-if sys.version_info < (2, 7,):
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-
-if sys.version_info.major == 3:
-    unicode = str
-
 class LookupLib(object):
     """
 
@@ -55,7 +41,7 @@ class LookupLib(object):
     lookup against the Clublog API or QRZ.com.
 
     The entire lookup data (where database files are downloaded) can also be copied into Redis, which an extremely
-    fast in-memory Key/Value store. A LookupLib object can be instanciated to perform then all lookups in Redis,
+    fast in-memory Key/Value store. A LookupLib object can be instantiated to perform then all lookups in Redis,
     instead processing and loading the data from Internet / File. This saves some time and allows several instances
     of :py:class:`LookupLib` to query the same data concurrently.
 
@@ -80,10 +66,7 @@ class LookupLib(object):
             self._logger = logger
         else:
             self._logger = logging.getLogger(__name__)
-            if sys.version_info[:2] == (2, 6):
-                self._logger.addHandler(NullHandler())
-            else:
-                self._logger.addHandler(logging.NullHandler())
+            self._logger.addHandler(logging.NullHandler())
 
         self._apikey = apikey
         self._apiv = apiv
@@ -131,18 +114,15 @@ class LookupLib(object):
             "agent" : agent
         }
 
-        if sys.version_info.major == 3:
-            encodeurl = url + "?" + urllib.parse.urlencode(params)
-        else:
-            encodeurl = url + "?" + urllib.urlencode(params)
+        encodeurl = url + "?" + urllib.parse.urlencode(params)
         response = requests.get(encodeurl, timeout=10)
-        doc = BeautifulSoup(response.text, "html.parser")
+        doc = BeautifulSoup(response.text, "xml")
         session_key = None
-        if doc.session.key:
-            session_key = doc.session.key.text
+        if doc.QRZDatabase.Session.Key:
+            session_key = doc.QRZDatabase.Session.Key.text
         else:
-            if doc.session.error:
-                raise ValueError(doc.session.error.text)
+            if doc.QRZDatabase.Session.Error:
+                raise ValueError(doc.QRZDatabase.Session.Error.text)
             else:
                 raise ValueError("Could not retrieve Session Key from QRZ.com")
 
@@ -334,7 +314,7 @@ class LookupLib(object):
 
         Args:
             callsign (string): Amateur radio callsign
-            timestamp (datetime, optional): datetime in UTC (tzinfo=pytz.UTC)
+            timestamp (datetime, optional): datetime in UTC (tzinfo=timezone.utc)
 
         Returns:
             dict: Dictionary containing the country specific data of the callsign
@@ -347,10 +327,9 @@ class LookupLib(object):
            The following code queries the the online Clublog API for the callsign "VK9XO" on a specific date.
 
            >>> from pyhamtools import LookupLib
-           >>> from datetime import datetime
-           >>> import pytz
+           >>> from datetime import datetime, timezone
            >>> my_lookuplib = LookupLib(lookuptype="clublogapi", apikey="myapikey")
-           >>> timestamp = datetime(year=1962, month=7, day=7, tzinfo=pytz.UTC)
+           >>> timestamp = datetime(year=1962, month=7, day=7, tzinfo=timezone.utc)
            >>> print my_lookuplib.lookup_callsign("VK9XO", timestamp)
            {
             'country': u'CHRISTMAS ISLAND',
@@ -374,7 +353,7 @@ class LookupLib(object):
         """
         callsign = callsign.strip().upper()
         if timestamp is None:
-            timestamp = datetime.utcnow().replace(tzinfo=UTC)
+            timestamp = datetime.now(timezone.utc)
 
         if self._lookuptype == "clublogapi":
             callsign_data =  self._lookup_clublogAPI(callsign=callsign, timestamp=timestamp, apikey=self._apikey)
@@ -499,7 +478,7 @@ class LookupLib(object):
 
         Args:
             prefix (string): Prefix of a Amateur Radio callsign
-            timestamp (datetime, optional): datetime in UTC (tzinfo=pytz.UTC)
+            timestamp (datetime, optional): datetime in UTC (tzinfo=timezone.utc)
 
         Returns:
             dict: Dictionary containing the country specific data of the Prefix
@@ -536,7 +515,7 @@ class LookupLib(object):
 
         prefix = prefix.strip().upper()
         if timestamp is None:
-            timestamp = datetime.utcnow().replace(tzinfo=UTC)
+            timestamp = datetime.now(timezone.utc)
 
         if self._lookuptype == "clublogxml" or self._lookuptype == "countryfile":
 
@@ -556,7 +535,7 @@ class LookupLib(object):
 
         Args:
             callsign (string): Amateur Radio callsign
-            timestamp (datetime, optional): datetime in UTC (tzinfo=pytz.UTC)
+            timestamp (datetime, optional): datetime in UTC (tzinfo=timezone.utc)
 
         Returns:
             bool: True if a record exists for this callsign (at the given time)
@@ -569,13 +548,12 @@ class LookupLib(object):
            The following code checks the Clublog XML database if the operation is valid for two dates.
 
            >>> from pyhamtools import LookupLib
-           >>> from datetime import datetime
-           >>> import pytz
+           >>> from datetime import datetime, timezone
            >>> my_lookuplib = LookupLib(lookuptype="clublogxml", apikey="myapikey")
            >>> print my_lookuplib.is_invalid_operation("5W1CFN")
            True
            >>> try:
-           >>>   timestamp = datetime(year=2012, month=1, day=31).replace(tzinfo=pytz.UTC)
+           >>>   timestamp = datetime(year=2012, month=1, day=31, tzinfo=timezone.utc)
            >>>   my_lookuplib.is_invalid_operation("5W1CFN", timestamp)
            >>> except KeyError:
            >>>   print "Seems to be invalid operation before 31.1.2012"
@@ -591,7 +569,7 @@ class LookupLib(object):
 
         callsign = callsign.strip().upper()
         if timestamp is None:
-            timestamp = datetime.utcnow().replace(tzinfo=UTC)
+            timestamp = datetime.now(timezone.utc)
 
         if self._lookuptype == "clublogxml":
 
@@ -645,7 +623,7 @@ class LookupLib(object):
 
         Args:
         callsign (string): Amateur radio callsign
-        timestamp (datetime, optional): datetime in UTC (tzinfo=pytz.UTC)
+        timestamp (datetime, optional): datetime in UTC (tzinfo=timezone.utc)
 
         Returns:
             int: Value of the the CQ Zone exception which exists for this callsign (at the given time)
@@ -675,7 +653,7 @@ class LookupLib(object):
 
         callsign = callsign.strip().upper()
         if timestamp is None:
-            timestamp = datetime.utcnow().replace(tzinfo=UTC)
+            timestamp = datetime.now(timezone.utc)
 
         if self._lookuptype == "clublogxml":
 
@@ -689,7 +667,7 @@ class LookupLib(object):
         #no matching case
         raise KeyError
 
-    def _lookup_clublogAPI(self, callsign=None, timestamp=None, url="https://secure.clublog.org/dxcc", apikey=None):
+    def _lookup_clublogAPI(self, callsign=None, timestamp=None, url="https://cdn.clublog.org/dxcc", apikey=None):
         """ Set up the Lookup object for Clublog Online API
         """
 
@@ -704,12 +682,9 @@ class LookupLib(object):
         }
 
         if timestamp is None:
-            timestamp = datetime.utcnow().replace(tzinfo=UTC)
+            timestamp = datetime.now(timezone.utc)
 
-        if sys.version_info.major == 3:
-            encodeurl = url + "?" + urllib.parse.urlencode(params)
-        else:
-            encodeurl = url + "?" + urllib.urlencode(params)
+        encodeurl = url + "?" + urllib.parse.urlencode(params)
         response = requests.get(encodeurl, timeout=5)
 
         if not self._check_html_response(response):
@@ -740,10 +715,7 @@ class LookupLib(object):
             "callsign" : callsign,
         }
 
-        if sys.version_info.major == 3:
-            encodeurl = url + "?" + urllib.parse.urlencode(params)
-        else:
-            encodeurl = url + "?" + urllib.urlencode(params)
+        encodeurl = url + "?" + urllib.parse.urlencode(params)
         response = requests.get(encodeurl, timeout=5)
         return response
 
@@ -756,10 +728,7 @@ class LookupLib(object):
             "dxcc" : str(dxcc_or_callsign),
         }
 
-        if sys.version_info.major == 3:
-            encodeurl = url + "?" + urllib.parse.urlencode(params)
-        else:
-            encodeurl = url + "?" + urllib.urlencode(params)
+        encodeurl = url + "?" + urllib.parse.urlencode(params)
         response = requests.get(encodeurl, timeout=5)
         return response
 
@@ -769,43 +738,43 @@ class LookupLib(object):
 
         response = self._request_dxcc_info_from_qrz(dxcc_or_callsign, apikey, apiv=apiv)
 
-        root = BeautifulSoup(response.text, "html.parser")
+        root = BeautifulSoup(response.text, "xml")
         lookup = {}
 
-        if root.error: #try to get a new session key and try to request again
+        if root.Error: #try to get a new session key and try to request again
 
-            if re.search('No DXCC Information for', root.error.text, re.I):  #No data available for callsign
-                raise KeyError(root.error.text)
-            elif re.search('Session Timeout', root.error.text, re.I): # Get new session key
+            if re.search('No DXCC Information for', root.Error.text, re.I):  #No data available for callsign
+                raise KeyError(root.Error.text)
+            elif re.search('Session Timeout', root.Error.text, re.I): # Get new session key
                 self._apikey = apikey = self._get_qrz_session_key(self._username, self._pwd)
                 response = self._request_dxcc_info_from_qrz(dxcc_or_callsign, apikey)
-                root = BeautifulSoup(response.text, "html.parser")
+                root = BeautifulSoup(response.text, "xml")
             else:
                 raise AttributeError("Session Key Missing") #most likely session key missing or invalid
 
-        if root.dxcc is None:
+        if root.DXCC is None:
             raise ValueError
 
-        if root.dxcc.dxcc:
-            lookup[const.ADIF] = int(root.dxcc.dxcc.text)
-        if root.dxcc.cc:
-            lookup['cc'] = root.dxcc.cc.text
-        if root.dxcc.cc:
-            lookup['ccc'] = root.dxcc.ccc.text
+        if root.DXCC.dxcc:
+            lookup[const.ADIF] = int(root.DXCC.dxcc.text)
+        if root.DXCC.cc:
+            lookup['cc'] = root.DXCC.cc.text
+        if root.DXCC.ccc:
+            lookup['ccc'] = root.DXCC.ccc.text
         if root.find('name'):
             lookup[const.COUNTRY] = root.find('name').get_text()
-        if root.dxcc.continent:
-            lookup[const.CONTINENT] = root.dxcc.continent.text
-        if root.dxcc.ituzone:
-            lookup[const.ITUZ] = int(root.dxcc.ituzone.text)
-        if root.dxcc.cqzone:
-            lookup[const.CQZ] = int(root.dxcc.cqzone.text)
-        if root.dxcc.timezone:
-            lookup['timezone'] = float(root.dxcc.timezone.text)
-        if root.dxcc.lat:
-            lookup[const.LATITUDE] = float(root.dxcc.lat.text)
-        if root.dxcc.lon:
-            lookup[const.LONGITUDE] = float(root.dxcc.lon.text)
+        if root.DXCC.continent:
+            lookup[const.CONTINENT] = root.DXCC.continent.text
+        if root.DXCC.ituzone:
+            lookup[const.ITUZ] = int(root.DXCC.ituzone.text)
+        if root.DXCC.cqzone:
+            lookup[const.CQZ] = int(root.DXCC.cqzone.text)
+        if root.DXCC.timezone:
+            lookup['timezone'] = float(root.DXCC.timezone.text)
+        if root.DXCC.lat:
+            lookup[const.LATITUDE] = float(root.DXCC.lat.text)
+        if root.DXCC.lon:
+            lookup[const.LONGITUDE] = float(root.DXCC.lon.text)
 
         return lookup
 
@@ -821,160 +790,156 @@ class LookupLib(object):
 
         response = self._request_callsign_info_from_qrz(callsign, apikey, apiv)
 
-        root = BeautifulSoup(response.text, "html.parser")
+        root = BeautifulSoup(response.text, "xml")
         lookup = {}
 
-        if root.error:
+        if root.Error:
 
-            if re.search('Not found', root.error.text, re.I):  #No data available for callsign
-                raise KeyError(root.error.text)
+            if re.search('Not found', root.Error.text, re.I):  #No data available for callsign
+                raise KeyError(root.Error.text)
 
             #try to get a new session key and try to request again
-            elif re.search('Session Timeout', root.error.text, re.I) or re.search('Invalid session key', root.error.text, re.I):
+            elif re.search('Session Timeout', root.Error.text, re.I) or re.search('Invalid session key', root.Error.text, re.I):
                 apikey = self._get_qrz_session_key(self._username, self._pwd)
                 response = self._request_callsign_info_from_qrz(callsign, apikey, apiv)
-                root = BeautifulSoup(response.text, "html.parser")
+                root = BeautifulSoup(response.text, "xml")
 
                 #if this fails again, raise error
-                if root.error:
+                if root.Error:
 
-                    if re.search('Not found', root.error.text, re.I):  #No data available for callsign
-                        raise KeyError(root.error.text)
+                    if re.search('Not found', root.Error.text, re.I):  #No data available for callsign
+                        raise KeyError(root.Error.text)
                     else:
-                        raise AttributeError(root.error.text) #most likely session key invalid
+                        raise AttributeError(root.Error.text) #most likely session key invalid
                 else:
                     #update API Key ob Lookup object
                     self._apikey = apikey
 
             else:
-                raise AttributeError(root.error.text) #most likely session key missing
+                raise AttributeError(root.Error.text) #most likely session key missing
 
-        if root.callsign is None:
+        if root.Callsign is None:
             raise ValueError
 
-        if root.callsign.call:
-            lookup[const.CALLSIGN] = root.callsign.call.text
-        if root.callsign.xref:
-            lookup[const.XREF] = root.callsign.xref.text
-        if root.callsign.aliases:
-            lookup[const.ALIASES] = root.callsign.aliases.text.split(',')
-        if root.callsign.dxcc:
-            lookup[const.ADIF] = int(root.callsign.dxcc.text)
-        if root.callsign.fname:
-            lookup[const.FNAME] = root.callsign.fname.text
-        if root.callsign.find("name"):
-            lookup[const.NAME] = root.callsign.find('name').get_text()
-        if root.callsign.addr1:
-            lookup[const.ADDR1] = root.callsign.addr1.text
-        if root.callsign.addr2:
-            lookup[const.ADDR2] = root.callsign.addr2.text
-        if root.callsign.state:
-            lookup[const.STATE] = root.callsign.state.text
-        if root.callsign.zip:
-            lookup[const.ZIPCODE] = root.callsign.zip.text
-        if root.callsign.country:
-            lookup[const.COUNTRY] = root.callsign.country.text
-        if root.callsign.ccode:
-            lookup[const.CCODE] = int(root.callsign.ccode.text)
-        if root.callsign.lat:
-            lookup[const.LATITUDE] = float(root.callsign.lat.text)
-        if root.callsign.lon:
-            lookup[const.LONGITUDE] = float(root.callsign.lon.text)
-        if root.callsign.grid:
-            lookup[const.LOCATOR] = root.callsign.grid.text
-        if root.callsign.county:
-            lookup[const.COUNTY] = root.callsign.county.text
-        if root.callsign.fips:
-            lookup[const.FIPS] = int(root.callsign.fips.text) # check type
-        if root.callsign.land:
-            lookup[const.LAND] = root.callsign.land.text
-        if root.callsign.efdate:
+        if root.Callsign.call:
+            lookup[const.CALLSIGN] = root.Callsign.call.text
+        if root.Callsign.xref:
+            lookup[const.XREF] = root.Callsign.xref.text
+        if root.Callsign.aliases:
+            lookup[const.ALIASES] = root.Callsign.aliases.text.split(',')
+        if root.Callsign.dxcc:
+            lookup[const.ADIF] = int(root.Callsign.dxcc.text)
+        if root.Callsign.fname:
+            lookup[const.FNAME] = root.Callsign.fname.text
+        if root.Callsign.find("name"):
+            lookup[const.NAME] = root.Callsign.find('name').get_text()
+        if root.Callsign.addr1:
+            lookup[const.ADDR1] = root.Callsign.addr1.text
+        if root.Callsign.addr2:
+            lookup[const.ADDR2] = root.Callsign.addr2.text
+        if root.Callsign.state:
+            lookup[const.STATE] = root.Callsign.state.text
+        if root.Callsign.zip:
+            lookup[const.ZIPCODE] = root.Callsign.zip.text
+        if root.Callsign.country:
+            lookup[const.COUNTRY] = root.Callsign.country.text
+        if root.Callsign.ccode:
+            lookup[const.CCODE] = int(root.Callsign.ccode.text)
+        if root.Callsign.lat:
+            lookup[const.LATITUDE] = float(root.Callsign.lat.text)
+        if root.Callsign.lon:
+            lookup[const.LONGITUDE] = float(root.Callsign.lon.text)
+        if root.Callsign.grid:
+            lookup[const.LOCATOR] = root.Callsign.grid.text
+        if root.Callsign.county:
+            lookup[const.COUNTY] = root.Callsign.county.text
+        if root.Callsign.fips:
+            lookup[const.FIPS] = int(root.Callsign.fips.text) # check type
+        if root.Callsign.land:
+            lookup[const.LAND] = root.Callsign.land.text
+        if root.Callsign.efdate:
             try:
-                lookup[const.EFDATE] = datetime.strptime(root.callsign.efdate.text, '%Y-%m-%d').replace(tzinfo=UTC)
+                lookup[const.EFDATE] = datetime.strptime(root.Callsign.efdate.text, '%Y-%m-%d').replace(tzinfo=timezone.utc)
             except ValueError:
-                self._logger.debug("[QRZ.com] efdate: Invalid DateTime; " + callsign + " " + root.callsign.efdate.text)
-        if root.callsign.expdate:
+                self._logger.debug("[QRZ.com] efdate: Invalid DateTime; " + callsign + " " + root.Callsign.efdate.text)
+        if root.Callsign.expdate:
             try:
-                lookup[const.EXPDATE] = datetime.strptime(root.callsign.expdate.text, '%Y-%m-%d').replace(tzinfo=UTC)
+                lookup[const.EXPDATE] = datetime.strptime(root.Callsign.expdate.text, '%Y-%m-%d').replace(tzinfo=timezone.utc)
             except ValueError:
-                self._logger.debug("[QRZ.com] expdate: Invalid DateTime; " + callsign + " " + root.callsign.expdate.text)
-        if root.callsign.p_call:
-            lookup[const.P_CALL] = root.callsign.p_call.text
-        if root.callsign.find('class'):
-             lookup[const.LICENSE_CLASS] = root.callsign.find('class').get_text()
-        if root.callsign.codes:
-            lookup[const.CODES] = root.callsign.codes.text
-        if root.callsign.qslmgr:
-            lookup[const.QSLMGR] = root.callsign.qslmgr.text
-        if root.callsign.email:
-            lookup[const.EMAIL] = root.callsign.email.text
-        if root.callsign.url:
-            lookup[const.URL] = root.callsign.url.text
-        if root.callsign.u_views:
-            lookup[const.U_VIEWS] = int(root.callsign.u_views.text)
-        if root.callsign.bio:
-            lookup[const.BIO] = root.callsign.bio.text
-        if root.callsign.biodate:
+                self._logger.debug("[QRZ.com] expdate: Invalid DateTime; " + callsign + " " + root.Callsign.expdate.text)
+        if root.Callsign.p_call:
+            lookup[const.P_CALL] = root.Callsign.p_call.text
+        if root.Callsign.find('class'):
+             lookup[const.LICENSE_CLASS] = root.Callsign.find('class').get_text()
+        if root.Callsign.codes:
+            lookup[const.CODES] = root.Callsign.codes.text
+        if root.Callsign.qslmgr:
+            lookup[const.QSLMGR] = root.Callsign.qslmgr.text
+        if root.Callsign.email:
+            lookup[const.EMAIL] = root.Callsign.email.text
+        if root.Callsign.url:
+            lookup[const.URL] = root.Callsign.url.text
+        if root.Callsign.u_views:
+            lookup[const.U_VIEWS] = int(root.Callsign.u_views.text)
+        if root.Callsign.bio:
+            lookup[const.BIO] = root.Callsign.bio.text
+        if root.Callsign.biodate:
             try:
-                lookup[const.BIODATE] = datetime.strptime(root.callsign.biodate.text, '%Y-%m-%d %H:%M:%S').replace(tzinfo=UTC)
+                lookup[const.BIODATE] = datetime.strptime(root.Callsign.biodate.text, '%Y-%m-%d %H:%M:%S').replace(tzinfo=timezone.utc)
             except ValueError:
                 self._logger.warning("[QRZ.com] biodate: Invalid DateTime; " + callsign)
-        if root.callsign.image:
-            lookup[const.IMAGE] = root.callsign.image.text
-        if root.callsign.imageinfo:
-            lookup[const.IMAGE_INFO] = root.callsign.imageinfo.text
-        if root.callsign.serial:
-            lookup[const.SERIAL] = long(root.callsign.serial.text)
-        if root.callsign.moddate:
+        if root.Callsign.image:
+            lookup[const.IMAGE] = root.Callsign.image.text
+        if root.Callsign.imageinfo:
+            lookup[const.IMAGE_INFO] = root.Callsign.imageinfo.text
+        if root.Callsign.serial:
+            lookup[const.SERIAL] = long(root.Callsign.serial.text)
+        if root.Callsign.moddate:
             try:
-                lookup[const.MODDATE] = datetime.strptime(root.callsign.moddate.text, '%Y-%m-%d %H:%M:%S').replace(tzinfo=UTC)
+                lookup[const.MODDATE] = datetime.strptime(root.Callsign.moddate.text, '%Y-%m-%d %H:%M:%S').replace(tzinfo=timezone.utc)
             except ValueError:
                 self._logger.warning("[QRZ.com] moddate: Invalid DateTime; " + callsign)
-        if root.callsign.MSA:
-            lookup[const.MSA] = int(root.callsign.MSA.text)
-        if root.callsign.AreaCode:
-            lookup[const.AREACODE] = int(root.callsign.AreaCode.text)
-        if root.callsign.TimeZone:
-            lookup[const.TIMEZONE] = int(root.callsign.TimeZone.text)
-        if root.callsign.GMTOffset:
-            lookup[const.GMTOFFSET] = float(root.callsign.GMTOffset.text)
-        if root.callsign.DST:
-            if root.callsign.DST.text == "Y":
+        if root.Callsign.MSA:
+            lookup[const.MSA] = int(root.Callsign.MSA.text)
+        if root.Callsign.AreaCode:
+            lookup[const.AREACODE] = int(root.Callsign.AreaCode.text)
+        if root.Callsign.TimeZone:
+            lookup[const.TIMEZONE] = root.Callsign.TimeZone.text
+        if root.Callsign.GMTOffset:
+            lookup[const.GMTOFFSET] = float(root.Callsign.GMTOffset.text)
+        if root.Callsign.DST:
+            if root.Callsign.DST.text == "Y":
                 lookup[const.DST] = True
             else:
                 lookup[const.DST] = False
-        if root.callsign.eqsl:
-            if root.callsign.eqsl.text == "1":
+        if root.Callsign.eqsl:
+            if root.Callsign.eqsl.text == "1":
                 lookup[const.EQSL] = True
             else:
                 lookup[const.EQSL] = False
-        if root.callsign.mqsl:
-            if root.callsign.mqsl.text == "1":
+        if root.Callsign.mqsl:
+            if root.Callsign.mqsl.text == "1":
                 lookup[const.MQSL] = True
             else:
                 lookup[const.MQSL] = False
-        if root.callsign.cqzone:
-            lookup[const.CQZ] = int(root.callsign.cqzone.text)
-        if root.callsign.ituzone:
-            lookup[const.ITUZ] = int(root.callsign.ituzone.text)
-        if root.callsign.born:
-            lookup[const.BORN] = int(root.callsign.born.text)
-        if root.callsign.user:
-            lookup[const.USER_MGR] = root.callsign.user.text
-        if root.callsign.lotw:
-            if root.callsign.lotw.text == "1":
+        if root.Callsign.cqzone:
+            lookup[const.CQZ] = int(root.Callsign.cqzone.text)
+        if root.Callsign.ituzone:
+            lookup[const.ITUZ] = int(root.Callsign.ituzone.text)
+        if root.Callsign.born:
+            lookup[const.BORN] = int(root.Callsign.born.text)
+        if root.Callsign.user:
+            lookup[const.USER_MGR] = root.Callsign.user.text
+        if root.Callsign.lotw:
+            if root.Callsign.lotw.text == "1":
                 lookup[const.LOTW] = True
             else:
                 lookup[const.LOTW] = False
-        if root.callsign.iota:
-            lookup[const.IOTA] = root.callsign.iota.text
-        if root.callsign.geoloc:
-            lookup[const.GEOLOC] = root.callsign.geoloc.text
+        if root.Callsign.iota:
+            lookup[const.IOTA] = root.Callsign.iota.text
+        if root.Callsign.geoloc:
+            lookup[const.GEOLOC] = root.Callsign.geoloc.text
 
-        # if sys.version_info >= (2,):
-        #     for item in lookup:
-        #         if isinstance(lookup[item], unicode):
-        #             print item, repr(lookup[item])
         return lookup
 
     def _load_clublogXML(self,
@@ -1135,7 +1100,7 @@ class LookupLib(object):
             if cty_date:
                 cty_date = cty_date.group(0).replace("date=", "").replace("'", "")
                 cty_date = datetime.strptime(cty_date[:19], '%Y-%m-%dT%H:%M:%S')
-                cty_date.replace(tzinfo=UTC)
+                cty_date.replace(tzinfo=timezone.utc)
                 cty_header["Date"] = cty_date
 
             cty_ns = re.search("xmlns='.+[']", raw_header)
@@ -1146,7 +1111,7 @@ class LookupLib(object):
             if len(cty_header) == 2:
                 self._logger.debug("Header successfully retrieved from CTY File")
             elif len(cty_header) < 2:
-                self._logger.warning("Header could only be partically retrieved from CTY File")
+                self._logger.warning("Header could only be partially retrieved from CTY File")
                 self._logger.warning("Content of Header: ")
                 for key in cty_header:
                     self._logger.warning(str(key)+": "+str(cty_header[key]))
@@ -1215,10 +1180,10 @@ class LookupLib(object):
                     entity = {}
                     for item in cty_entity:
                         if item.tag == "name":
-                            entity[const.COUNTRY] = unicode(item.text)
-                            self._logger.debug(unicode(item.text))
+                            entity[const.COUNTRY] = str(item.text)
+                            self._logger.debug(str(item.text))
                         elif item.tag == "prefix":
-                            entity[const.PREFIX] = unicode(item.text)
+                            entity[const.PREFIX] = str(item.text)
                         elif item.tag == "deleted":
                             if item.text == "TRUE":
                                 entity[const.DELETED] = True
@@ -1227,17 +1192,17 @@ class LookupLib(object):
                         elif item.tag == "cqz":
                             entity[const.CQZ] = int(item.text)
                         elif item.tag == "cont":
-                            entity[const.CONTINENT] = unicode(item.text)
+                            entity[const.CONTINENT] = str(item.text)
                         elif item.tag == "long":
                             entity[const.LONGITUDE] = float(item.text)
                         elif item.tag == "lat":
                             entity[const.LATITUDE] = float(item.text)
                         elif item.tag == "start":
                             dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                            entity[const.START] = dt.replace(tzinfo=UTC)
+                            entity[const.START] = dt.replace(tzinfo=timezone.utc)
                         elif item.tag == "end":
                             dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                            entity[const.END] = dt.replace(tzinfo=UTC)
+                            entity[const.END] = dt.replace(tzinfo=timezone.utc)
                         elif item.tag == "whitelist":
                             if item.text == "TRUE":
                                 entity[const.WHITELIST] = True
@@ -1245,10 +1210,10 @@ class LookupLib(object):
                                 entity[const.WHITELIST] = False
                         elif item.tag == "whitelist_start":
                             dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                            entity[const.WHITELIST_START] = dt.replace(tzinfo=UTC)
+                            entity[const.WHITELIST_START] = dt.replace(tzinfo=timezone.utc)
                         elif item.tag == "whitelist_end":
                             dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                            entity[const.WHITELIST_END] = dt.replace(tzinfo=UTC)
+                            entity[const.WHITELIST_END] = dt.replace(tzinfo=timezone.utc)
                 except AttributeError:
                     self._logger.error("Error while processing: ")
                 entities[int(cty_entity[0].text)] = entity
@@ -1269,23 +1234,23 @@ class LookupLib(object):
                         else:
                             call_exceptions_index[call] = [int(cty_exception.attrib["record"])]
                     elif item.tag == "entity":
-                        call_exception[const.COUNTRY] = unicode(item.text)
+                        call_exception[const.COUNTRY] = str(item.text)
                     elif item.tag == "adif":
                         call_exception[const.ADIF] = int(item.text)
                     elif item.tag == "cqz":
                         call_exception[const.CQZ] = int(item.text)
                     elif item.tag == "cont":
-                        call_exception[const.CONTINENT] = unicode(item.text)
+                        call_exception[const.CONTINENT] = str(item.text)
                     elif item.tag == "long":
                         call_exception[const.LONGITUDE] = float(item.text)
                     elif item.tag == "lat":
                         call_exception[const.LATITUDE] = float(item.text)
                     elif item.tag == "start":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        call_exception[const.START] = dt.replace(tzinfo=UTC)
+                        call_exception[const.START] = dt.replace(tzinfo=timezone.utc)
                     elif item.tag == "end":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        call_exception[const.END] = dt.replace(tzinfo=UTC)
+                        call_exception[const.END] = dt.replace(tzinfo=timezone.utc)
                     call_exceptions[int(cty_exception.attrib["record"])] = call_exception
 
             self._logger.debug(str(len(call_exceptions))+" Exceptions added")
@@ -1310,23 +1275,23 @@ class LookupLib(object):
                         else:
                             prefixes_index[call] = [int(cty_prefix.attrib["record"])]
                     if item.tag == "entity":
-                        prefix[const.COUNTRY] = unicode(item.text)
+                        prefix[const.COUNTRY] = str(item.text)
                     elif item.tag == "adif":
                         prefix[const.ADIF] = int(item.text)
                     elif item.tag == "cqz":
                         prefix[const.CQZ] = int(item.text)
                     elif item.tag == "cont":
-                        prefix[const.CONTINENT] = unicode(item.text)
+                        prefix[const.CONTINENT] = str(item.text)
                     elif item.tag == "long":
                         prefix[const.LONGITUDE] = float(item.text)
                     elif item.tag == "lat":
                         prefix[const.LATITUDE] = float(item.text)
                     elif item.tag == "start":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        prefix[const.START] = dt.replace(tzinfo=UTC)
+                        prefix[const.START] = dt.replace(tzinfo=timezone.utc)
                     elif item.tag == "end":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        prefix[const.END] = dt.replace(tzinfo=UTC)
+                        prefix[const.END] = dt.replace(tzinfo=timezone.utc)
                     prefixes[int(cty_prefix.attrib["record"])] = prefix
 
             self._logger.debug(str(len(prefixes))+" Prefixes added")
@@ -1349,10 +1314,10 @@ class LookupLib(object):
 
                     elif item.tag == "start":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        invalid_operation[const.START] = dt.replace(tzinfo=UTC)
+                        invalid_operation[const.START] = dt.replace(tzinfo=timezone.utc)
                     elif item.tag == "end":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        invalid_operation[const.END] = dt.replace(tzinfo=UTC)
+                        invalid_operation[const.END] = dt.replace(tzinfo=timezone.utc)
                     invalid_operations[int(cty_inv_operation.attrib["record"])] = invalid_operation
 
             self._logger.debug(str(len(invalid_operations))+" Invalid Operations added")
@@ -1378,10 +1343,10 @@ class LookupLib(object):
                         zoneException[const.CQZ] = int(item.text)
                     elif item.tag == "start":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        zoneException[const.START] = dt.replace(tzinfo=UTC)
+                        zoneException[const.START] = dt.replace(tzinfo=timezone.utc)
                     elif item.tag == "end":
                         dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        zoneException[const.END] = dt.replace(tzinfo=UTC)
+                        zoneException[const.END] = dt.replace(tzinfo=timezone.utc)
                     zone_exceptions[int(cty_zone_exception.attrib["record"])] = zoneException
 
             self._logger.debug(str(len(zone_exceptions))+" Zone Exceptions added")
@@ -1437,12 +1402,12 @@ class LookupLib(object):
         for item in cty_list:
             entry = {}
             call = str(item)
-            entry[const.COUNTRY] = unicode(cty_list[item]["Country"])
+            entry[const.COUNTRY] = str(cty_list[item]["Country"])
             if mapping:
                  entry[const.ADIF] = int(mapping[cty_list[item]["Country"]])
             entry[const.CQZ] = int(cty_list[item]["CQZone"])
             entry[const.ITUZ] = int(cty_list[item]["ITUZone"])
-            entry[const.CONTINENT] = unicode(cty_list[item]["Continent"])
+            entry[const.CONTINENT] = str(cty_list[item]["Continent"])
             entry[const.LATITUDE] = float(cty_list[item]["Latitude"])
             entry[const.LONGITUDE] = float(cty_list[item]["Longitude"])*(-1)
 
@@ -1534,17 +1499,17 @@ class LookupLib(object):
             elif item == const.LONGITUDE:
                 my_dict[item] = float(my_dict[item])
             elif item == const.START:
-                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=UTC)
+                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=timezone.utc)
             elif item == const.END:
-                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=UTC)
+                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=timezone.utc)
             elif item == const.WHITELIST_START:
-                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=UTC)
+                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=timezone.utc)
             elif item == const.WHITELIST_END:
-                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=UTC)
+                my_dict[item] = datetime.strptime(my_dict[item], '%Y-%m-%d%H:%M:%S').replace(tzinfo=timezone.utc)
             elif item == const.WHITELIST:
                 my_dict[item] = self._str_to_bool(my_dict[item])
             else:
-                my_dict[item] = unicode(my_dict[item])
+                my_dict[item] = str(my_dict[item])
 
         return my_dict
 
