@@ -1,13 +1,8 @@
-from __future__ import unicode_literals
 import pytest
-import sys
 
 from pyhamtools.lookuplib import LookupLib
 from pyhamtools.exceptions import APIKeyMissingError
 
-if sys.version_info.major == 3:
-    unicode = str
-
 @pytest.fixture(scope="function", params=[5, -5,  "", "foo bar", 11.5, {}, [], None, ("foo", "bar")])
 def fixAnyValue(request):
     return request.param
@@ -41,5 +36,5 @@ class TestlookupLibHelper:
         with pytest.raises(TypeError):
             fixClublogApi._generate_random_word()
 
-        assert type(fixClublogApi._generate_random_word(5)) is unicode
+        assert type(fixClublogApi._generate_random_word(5)) is str
         assert len(fixClublogApi._generate_random_word(5)) == 5
